#!/usr/bin/env bash
DEPENDENCIES=$(mp_join "gobject-2.0 glib-2.0" "$DEPENDENCIES")

mp_mkdir $TARNAME
mp_source configure.ac $TARNAME "$PACKAGE" $BUGREPORT "$DEPENDENCIES"
mp_cp Makefile.am $TARNAME
mp_source AUTHORS $TARNAME "$AUTHOR" $BUGREPORT
mp_source ChangeLog $TARNAME "$AUTHOR" $BUGREPORT
mp_source README $TARNAME "$PACKAGE" "$DESCRIPTION"
mp_source NEWS $TARNAME

mp_mkdir $TARNAME/src
mp_source src/Makefile.am $TARNAME
mp_cp src/main.c $TARNAME
mp_cp src/g-hello-world.gob $TARNAME

mp_mkdir $TARNAME/m4
mp_cp m4/gob2.m4 $TARNAME

mp_exec "autoreconf -i" $TARNAME
